pub struct TokenThresholdCompressor { /* private fields */ }Expand description
Compresses message history when the total character count exceeds max_chars.
Uses an LLM to produce a one-sentence summary that replaces the middle messages (keeping the system prompt and the last user message intact).
Implementations
Sourceimpl TokenThresholdCompressor
impl TokenThresholdCompressor
Sourcepub fn new(
max_chars: usize,
llm: Arc<dyn Runnable<LlmRequest, LlmResponse>>,
) -> Self
pub fn new( max_chars: usize, llm: Arc<dyn Runnable<LlmRequest, LlmResponse>>, ) -> Self
max_chars / 4 approximates the token count.